@@ -13,11 +13,6 @@ changeSaveFile <- function(optObj,saveFile = NULL) {
   # See if saveFile can be written to.
   if (!is.null(saveFile)) {
     if (toupper(substr(saveFile, nchar(saveFile)-4+1, nchar(saveFile))) != ".RDS") stop("saveFile is saved as an RDS using saveRDS() - please change file extension in saveFile parameter.")
-    if (file.access(saveFile,mode=2) != 0) {
-      message("saveFile is not writeable according to file.access(). Continue? [y/n]")
-      line <- readline()
-      if (tolower(line) == "y") invisible() else stop("Process Stopped by User.")
-    }
   }
   optObj$saveFile <- saveFile
   return(optObj)
